from machinetalk.protobuf.message_pb2 import Container
from machinetalk.protobuf.types_pb2 import *

# create the message container, reuse is more efficient
tx = Container()

# define the message
tx.Clear()
tx.type = MT_PING

# encode the message
encodedBuffer = tx.SerializeToString()

# print the buffer
print(encodedBuffer)



from machinetalk.protobuf.message_pb2 import Container
from machinetalk.protobuf.types_pb2 import *

encodedBuffer = ''.join(chr(x) for x in [0x08, 0xd2, 0x01])

# create the message container, reuse is more efficient
rx = Container()

# parse the encoded message
rx.ParseFromString(encodedBuffer)

# print the decoded message
print(rx)



"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from os import path

# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open

PROJECT = "machinetalk"
PROJECT_NAME = "%s-protobuf" % PROJECT
DESCRIPTION = "Protobuf Python modules for %s" % PROJECT
VERSION = "1.2.1"
AUTHOR = "Alexander Roessler"
AUTHOR_EMAIL = "alex@machinekoder.com"
PROJECT_URL = "https://github.com/machinekit/%s" % PROJECT_NAME
DOWNLOAD_URL = "https://github.com/machinekit/%s/archive/%s.tar.gz" % (
    PROJECT_NAME,
    VERSION,
)
KEYWORDS = "protobuf machinekit motion-control hal"

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name=PROJECT_NAME,
    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    # The project's main homepage.
    url=PROJECT_URL,
    download_url=DOWNLOAD_URL,
    # Author details
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 5 - Production/Stable",
        # Indicate who your project is intended for
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Object Brokering",
        # Pick your license as you wish (should match "license" above)
        "License :: OSI Approved :: MIT License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    # What does your project relate to?
    keywords=KEYWORDS,
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(where="build/python", exclude=["contrib", "docs", "tests"]),
    # Our packages live under src but src is not a package itself
    package_dir={"": "build/python"},
    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    # py_modules=["corenlp_protobuf"],
    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=["protobuf"],
    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={"dev": ["check-manifest"], "test": ["coverage"]},
    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={},
    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    data_files=[],
    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={},
)
